@@ -2,6 +2,7 @@
 # Distributed under the terms of the Modified BSD License.
 #
 
+import sys
 from ._version import version_info, __version__  # noqa
 
 # Allow dependencies to ipyleaflet to not be installed upon post-link for
@@ -10,6 +11,11 @@ from ._version import version_info, __version__  # noqa
 try:
     from .leaflet import *  # noqa
     from .basemaps import basemaps   # noqa
+
+    if "google.colab" in sys.modules:
+        from google.colab import output
+
+        output.enable_custom_widget_manager()
 except ImportError:
     pass
 
